Documentation
¶
Index ¶
Constants ¶
const ( JSON = "application/json" URLEncoded = "application/x-www-form-urlencoded" FormData = "multipart/form-data" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type APIClientConfig ¶ added in v0.10.0
type APIClientConfig struct {
APIVersion string
Beta bool
DebugEnabled bool
Edge *string
Region *string
RetryConfig RetryConfig
SubDomain string
}
APIClientConfig is the internal definition for each sub client which is used to call the Twilio API's
func NewAPIClientConfig ¶ added in v0.10.0
func NewAPIClientConfig(config *Config) *APIClientConfig
NewAPIClientConfig is an internal function for creating a api client config struct using default and user defined config
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
func (Client) GetRestyClient ¶
Used for testing purposes only
type Config ¶
type Config struct {
BackoffInterval *int
DebugEnabled *bool
Edge *string
Region *string
RetryAttempts *int
}
Config is the user defined configuration for the Twilio Client. This can be used to enable debugging, configuring the number of retry attempts, setting the time in milliseconds between retry attempts, edge location and region details
type RetryConfig ¶
RetryConfig defines the retry configuration for the HTTP client
Click to show internal directories.
Click to hide internal directories.