Documentation
¶
Overview ¶
Package local contains auto-generated files. DO NOT MODIFY
Package local contains auto-generated files. DO NOT MODIFY
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AvailablePhoneNumbersPageOptions ¶
type AvailablePhoneNumbersPageOptions struct {
PageSize *int
AreaCode *int
Contains *string
SmsEnabled *bool
MmsEnabled *bool
VoiceEnabled *bool
ExcludeAllAddressRequired *bool
ExcludeLocalAddressRequired *bool
ExcludeForeignAddressRequired *bool
Beta *bool
NearNumber *string
NearLatLong *string
Distance *int
InPostalCode *string
InRegion *string
InRateCenter *string
InLata *string
InLocality *string
FaxEnabled *bool
}
AvailablePhoneNumbersPageOptions defines the query options for the api operation
type AvailablePhoneNumbersPageResponse ¶
type AvailablePhoneNumbersPageResponse struct {
AvailablePhoneNumbers []PageAvailablePhoneNumberResponse `json:"available_phone_numbers"`
URI string `json:"uri"`
}
AvailablePhoneNumbersPageResponse defines the response fields for the available local phone numbers page
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client for managing available local phone number resources See https://www.twilio.com/docs/phone-numbers/api/availablephonenumber-resource for more details
func New ¶
func New(client *client.Client, properties ClientProperties) *Client
New creates a new instance of the local client
func (Client) Page ¶
func (c Client) Page(options *AvailablePhoneNumbersPageOptions) (*AvailablePhoneNumbersPageResponse, error)
Page retrieves a page of available local phone numbers See https://www.twilio.com/docs/phone-numbers/api/availablephonenumberlocal-resource#read-multiple-availablephonenumberlocal-resources for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) PageWithContext ¶
func (c Client) PageWithContext(context context.Context, options *AvailablePhoneNumbersPageOptions) (*AvailablePhoneNumbersPageResponse, error)
PageWithContext retrieves a page of available local phone numbers See https://www.twilio.com/docs/phone-numbers/api/availablephonenumberlocal-resource#read-multiple-availablephonenumberlocal-resources for more details
type ClientProperties ¶
ClientProperties are the properties required to manage the local resources
type PageAvailablePhoneNumberCapabilitiesResponse ¶ added in v0.6.0
type PageAvailablePhoneNumberResponse ¶
type PageAvailablePhoneNumberResponse struct {
AddressRequirements string `json:"address_requirements"`
Beta bool `json:"beta"`
Capabilities PageAvailablePhoneNumberCapabilitiesResponse `json:"capabilities"`
FriendlyName string `json:"friendly_name"`
IsoCountry string `json:"iso_country"`
Lata *string `json:"lata,omitempty"`
Latitude string `json:"latitude"`
Locality *string `json:"locality,omitempty"`
Longitude string `json:"longitude"`
PhoneNumber string `json:"phone_number"`
PostalCode *string `json:"postal_code,omitempty"`
RateCenter *string `json:"rate_center,omitempty"`
Region *string `json:"region,omitempty"`
}