Documentation
¶
Overview ¶
Package participant contains auto-generated files. DO NOT MODIFY
Package participant contains auto-generated files. DO NOT MODIFY
Package participant contains auto-generated files. DO NOT MODIFY
Package participant contains auto-generated files. DO NOT MODIFY
Index ¶
- type Client
- func (c Client) Delete() error
- func (c Client) DeleteWithContext(context context.Context) error
- func (c Client) Fetch() (*FetchParticipantResponse, error)
- func (c Client) FetchWithContext(context context.Context) (*FetchParticipantResponse, error)
- func (c Client) Update(input *UpdateParticipantInput) (*UpdateParticipantResponse, error)
- func (c Client) UpdateWithContext(context context.Context, input *UpdateParticipantInput) (*UpdateParticipantResponse, error)
- type ClientProperties
- type FetchParticipantResponse
- type UpdateParticipantInput
- type UpdateParticipantResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client for managing a specific participants resource See https://www.twilio.com/docs/voice/api/conference-participant-resource for more details
func New ¶
func New(client *client.Client, properties ClientProperties) *Client
New creates a new instance of the participant client
func (Client) Delete ¶
Delete removes a address participant from the conference See https://www.twilio.com/docs/voice/api/conference-participant-resource#delete-a-participant-resource for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) DeleteWithContext ¶
DeleteWithContext removes a address participant from the conference See https://www.twilio.com/docs/voice/api/conference-participant-resource#delete-a-participant-resource for more details
func (Client) Fetch ¶
func (c Client) Fetch() (*FetchParticipantResponse, error)
Fetch retrieves the participant resource See https://www.twilio.com/docs/voice/api/conference-participant-resource#fetch-a-participant-resource for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) FetchWithContext ¶
func (c Client) FetchWithContext(context context.Context) (*FetchParticipantResponse, error)
FetchWithContext retrieves the participant resource See https://www.twilio.com/docs/voice/api/conference-participant-resource#fetch-a-participant-resource for more details
func (Client) Update ¶
func (c Client) Update(input *UpdateParticipantInput) (*UpdateParticipantResponse, error)
Update modifies a participant resource See https://www.twilio.com/docs/voice/api/conference-participant-resource#update-a-participant-resource for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) UpdateWithContext ¶
func (c Client) UpdateWithContext(context context.Context, input *UpdateParticipantInput) (*UpdateParticipantResponse, error)
UpdateWithContext modifies a participant resource See https://www.twilio.com/docs/voice/api/conference-participant-resource#update-a-participant-resource for more details
type ClientProperties ¶
ClientProperties are the properties required to manage the participant resources
type FetchParticipantResponse ¶
type FetchParticipantResponse struct {
AccountSid string `json:"account_sid"`
CallSid string `json:"call_sid"`
CallSidToCoach *string `json:"call_sid_to_coach,omitempty"`
Coaching bool `json:"coaching"`
ConferenceSid string `json:"conference_sid"`
DateCreated utils.RFC2822Time `json:"date_created"`
DateUpdated *utils.RFC2822Time `json:"date_updated,omitempty"`
EndConferenceOnExit bool `json:"end_conference_on_exit"`
Hold bool `json:"hold"`
Label *string `json:"label,omitempty"`
Muted bool `json:"muted"`
StartConferenceOnEnter bool `json:"start_conference_on_enter"`
Status string `json:"status"`
}
FetchParticipantResponse defines the response fields for retrieving a participant
type UpdateParticipantInput ¶
type UpdateParticipantInput struct {
AnnounceMethod *string `form:"AnnounceMethod,omitempty"`
AnnounceURL *string `form:"AnnounceUrl,omitempty"`
BeepOnExit *bool `form:"BeepOnExit,omitempty"`
CallSidToCoach *string `form:"CallSidToCoach,omitempty"`
Coaching *bool `form:"Coaching,omitempty"`
EndConferenceOnExit *bool `form:"EndConferenceOnExit,omitempty"`
Hold *bool `form:"Hold,omitempty"`
HoldMethod *string `form:"HoldMethod,omitempty"`
HoldURL *string `form:"HoldUrl,omitempty"`
Muted *bool `form:"Muted,omitempty"`
WaitMethod *string `form:"WaitMethod,omitempty"`
WaitURL *string `form:"WaitUrl,omitempty"`
}
UpdateParticipantInput defines input fields for updating a participant
type UpdateParticipantResponse ¶
type UpdateParticipantResponse struct {
AccountSid string `json:"account_sid"`
CallSid string `json:"call_sid"`
CallSidToCoach *string `json:"call_sid_to_coach,omitempty"`
Coaching bool `json:"coaching"`
ConferenceSid string `json:"conference_sid"`
DateCreated utils.RFC2822Time `json:"date_created"`
DateUpdated *utils.RFC2822Time `json:"date_updated,omitempty"`
EndConferenceOnExit bool `json:"end_conference_on_exit"`
Hold bool `json:"hold"`
Label *string `json:"label,omitempty"`
Muted bool `json:"muted"`
StartConferenceOnEnter bool `json:"start_conference_on_enter"`
Status string `json:"status"`
}
UpdateParticipantResponse defines the response fields for the updated participant