Documentation
¶
Overview ¶
Package conversation contains auto-generated files. DO NOT MODIFY
Package conversation contains auto-generated files. DO NOT MODIFY
Package conversation contains auto-generated files. DO NOT MODIFY
Package conversation contains auto-generated files. DO NOT MODIFY
Index ¶
- type Client
- func (c Client) Delete() error
- func (c Client) DeleteWithContext(context context.Context) error
- func (c Client) Fetch() (*FetchConversationResponse, error)
- func (c Client) FetchWithContext(context context.Context) (*FetchConversationResponse, error)
- func (c Client) Update(input *UpdateConversationInput) (*UpdateConversationResponse, error)
- func (c Client) UpdateWithContext(context context.Context, input *UpdateConversationInput) (*UpdateConversationResponse, error)
- type ClientProperties
- type FetchConversationResponse
- type FetchConversationTimersResponse
- type UpdateConversationInput
- type UpdateConversationResponse
- type UpdateConversationTimersInput
- type UpdateConversationTimersResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
Message func(string) *message.Client
Messages *messages.Client
Participant func(string) *participant.Client
Participants *participants.Client
Webhook func(string) *webhook.Client
Webhooks *webhooks.Client
// contains filtered or unexported fields
}
Client for managing a specific conversation resource See https://www.twilio.com/docs/conversations/api/conversation-resource for more details
func New ¶
func New(client *client.Client, properties ClientProperties) *Client
New creates a new instance of the conversation client
func (Client) Delete ¶
Delete removes a conversation resource from the account See https://www.twilio.com/docs/conversations/api/conversation-resource#delete-a-conversation-resource for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) DeleteWithContext ¶
DeleteWithContext removes a conversation resource from the account See https://www.twilio.com/docs/conversations/api/conversation-resource#delete-a-conversation-resource for more details
func (Client) Fetch ¶
func (c Client) Fetch() (*FetchConversationResponse, error)
Fetch retrieves a conversation resource See https://www.twilio.com/docs/conversations/api/conversation-resource#fetch-a-conversation-resource for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) FetchWithContext ¶
func (c Client) FetchWithContext(context context.Context) (*FetchConversationResponse, error)
FetchWithContext retrieves a conversation resource See https://www.twilio.com/docs/conversations/api/conversation-resource#fetch-a-conversation-resource for more details
func (Client) Update ¶
func (c Client) Update(input *UpdateConversationInput) (*UpdateConversationResponse, error)
Update modifies a conversation resource See https://www.twilio.com/docs/conversations/api/conversation-resource#update-conversation for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) UpdateWithContext ¶
func (c Client) UpdateWithContext(context context.Context, input *UpdateConversationInput) (*UpdateConversationResponse, error)
UpdateWithContext modifies a conversation resource See https://www.twilio.com/docs/conversations/api/conversation-resource#update-conversation for more details
type ClientProperties ¶
ClientProperties are the properties required to manage the conversation resources
type FetchConversationResponse ¶
type FetchConversationResponse struct {
AccountSid string `json:"account_sid"`
Attributes string `json:"attributes"`
ChatServiceSid *string `json:"chat_service_sid,omitempty"`
DateCreated time.Time `json:"date_created"`
DateUpdated *time.Time `json:"date_updated,omitempty"`
FriendlyName *string `json:"friendly_name,omitempty"`
MessagingServiceSid *string `json:"messaging_service_sid,omitempty"`
Sid string `json:"sid"`
State string `json:"state"`
Timers FetchConversationTimersResponse `json:"timers"`
URL string `json:"url"`
UniqueName *string `json:"unique_name,omitempty"`
}
FetchConversationResponse defines the response fields for the retrieved conversation
type FetchConversationTimersResponse ¶ added in v0.6.0
type UpdateConversationInput ¶
type UpdateConversationInput struct {
Attributes *string `form:"Attributes,omitempty"`
DateCreated *utils.RFC2822Time `form:"DateCreated,omitempty"`
DateUpdated *utils.RFC2822Time `form:"DateUpdated,omitempty"`
FriendlyName *string `form:"FriendlyName,omitempty"`
MessagingServiceSid *string `form:"MessagingServiceSid,omitempty"`
State *string `form:"State,omitempty"`
Timers *UpdateConversationTimersInput `form:"Timers,omitempty"`
UniqueName *string `form:"UniqueName,omitempty"`
}
UpdateConversationInput defines input fields for updating a conversation resource
type UpdateConversationResponse ¶
type UpdateConversationResponse struct {
AccountSid string `json:"account_sid"`
Attributes string `json:"attributes"`
ChatServiceSid *string `json:"chat_service_sid,omitempty"`
DateCreated time.Time `json:"date_created"`
DateUpdated *time.Time `json:"date_updated,omitempty"`
FriendlyName *string `json:"friendly_name,omitempty"`
MessagingServiceSid *string `json:"messaging_service_sid,omitempty"`
Sid string `json:"sid"`
State string `json:"state"`
Timers UpdateConversationTimersResponse `json:"timers"`
URL string `json:"url"`
UniqueName *string `json:"unique_name,omitempty"`
}
UpdateConversationResponse defines the response fields for the updated conversation
type UpdateConversationTimersInput ¶ added in v0.6.0
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package message contains auto-generated files.
|
Package message contains auto-generated files. |
|
delivery_receipt
Package delivery_receipt contains auto-generated files.
|
Package delivery_receipt contains auto-generated files. |
|
delivery_receipts
Package delivery_receipts contains auto-generated files.
|
Package delivery_receipts contains auto-generated files. |
|
Package messages contains auto-generated files.
|
Package messages contains auto-generated files. |
|
Package participant contains auto-generated files.
|
Package participant contains auto-generated files. |
|
Package participants contains auto-generated files.
|
Package participants contains auto-generated files. |
|
Package webhook contains auto-generated files.
|
Package webhook contains auto-generated files. |
|
Package webhooks contains auto-generated files.
|
Package webhooks contains auto-generated files. |