Documentation
¶
Overview ¶
Package configuration contains auto-generated files. DO NOT MODIFY
Package configuration contains auto-generated files. DO NOT MODIFY
Package configuration contains auto-generated files. DO NOT MODIFY
Index ¶
- type Client
- func (c Client) Fetch() (*FetchConfigurationResponse, error)
- func (c Client) FetchWithContext(context context.Context) (*FetchConfigurationResponse, error)
- func (c Client) Update(input *UpdateConfigurationInput) (*UpdateConfigurationResponse, error)
- func (c Client) UpdateWithContext(context context.Context, input *UpdateConfigurationInput) (*UpdateConfigurationResponse, error)
- type FetchConfigurationIntegrationResponse
- type FetchConfigurationResponse
- type FetchConfigurationSkillResponse
- type FetchConfigurationTaskQueueResponse
- type FetchConfigurationWorkerChannelResponse
- type UpdateConfigurationInput
- type UpdateConfigurationIntegrationInput
- type UpdateConfigurationIntegrationResponse
- type UpdateConfigurationResponse
- type UpdateConfigurationSkillInput
- type UpdateConfigurationSkillResponse
- type UpdateConfigurationTaskQueueInput
- type UpdateConfigurationTaskQueueResponse
- type UpdateConfigurationWorkerChannelInput
- type UpdateConfigurationWorkerChannelResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client for managing a specific configuration resource See https://www.twilio.com/docs/flex/ui/configuration for more details
func (Client) Fetch ¶
func (c Client) Fetch() (*FetchConfigurationResponse, error)
Fetch retrieves a configuration resource Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) FetchWithContext ¶
func (c Client) FetchWithContext(context context.Context) (*FetchConfigurationResponse, error)
FetchWithContext retrieves a configuration resource
func (Client) Update ¶
func (c Client) Update(input *UpdateConfigurationInput) (*UpdateConfigurationResponse, error)
Update modifies a configuration resource Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) UpdateWithContext ¶
func (c Client) UpdateWithContext(context context.Context, input *UpdateConfigurationInput) (*UpdateConfigurationResponse, error)
UpdateWithContext modifies a configuration resource
type FetchConfigurationIntegrationResponse ¶ added in v0.6.0
type FetchConfigurationResponse ¶
type FetchConfigurationResponse struct {
AccountSid string `json:"account_sid"`
Attributes *interface{} `json:"attributes,omitempty"`
CallRecordingEnabled *bool `json:"call_recording_enabled,omitempty"`
CallRecordingWebhookURL *string `json:"call_recording_webhook_url,omitempty"`
ChatServiceInstanceSid *string `json:"chat_service_instance_sid,omitempty"`
CrmAttributes *interface{} `json:"crm_attributes,omitempty"`
CrmCallbackURL *string `json:"crm_callback_url,omitempty"`
CrmEnabled *bool `json:"crm_enabled,omitempty"`
CrmFallbackURL *string `json:"crm_fallback_url,omitempty"`
CrmType *string `json:"crm_type,omitempty"`
DateCreated time.Time `json:"date_created"`
DateUpdated *time.Time `json:"date_updated,omitempty"`
FlexServiceInstanceSid string `json:"flex_service_instance_sid"`
Integrations *[]FetchConfigurationIntegrationResponse `json:"integrations,omitempty"`
MessagingServiceInstanceSid *string `json:"messaging_service_instance_sid,omitempty"`
OutboundCallFlows *interface{} `json:"outbound_call_flows,omitempty"`
PluginServiceAttributes *interface{} `json:"plugin_service_attributes,omitempty"`
PluginServiceEnabled *bool `json:"plugin_service_enabled,omitempty"`
PublicAttributes *interface{} `json:"public_attributes,omitempty"`
QueueStatsConfiguration *interface{} `json:"queue_stats_configuration,omitempty"`
RuntimeDomain string `json:"runtime_domain"`
ServerlessServiceSids *[]string `json:"serverless_service_sids,omitempty"`
ServiceVersion *string `json:"service_version,omitempty"`
Status string `json:"status"`
TaskRouterOfflineActivitySid string `json:"taskrouter_offline_activity_sid"`
TaskRouterSkills *[]FetchConfigurationSkillResponse `json:"taskrouter_skills,omitempty"`
TaskRouterTargetTaskQueueSid string `json:"taskrouter_target_taskqueue_sid"`
TaskRouterTargetWorkflowSid string `json:"taskrouter_target_workflow_sid"`
TaskRouterTaskQueues *[]FetchConfigurationTaskQueueResponse `json:"taskrouter_taskqueues,omitempty"`
TaskRouterWorkerAttributes *map[string]interface{} `json:"taskrouter_worker_attributes,omitempty"`
TaskRouterWorkerChannels *map[string][]FetchConfigurationWorkerChannelResponse `json:"taskrouter_worker_channels,omitempty"`
TaskRouterWorkspaceSid string `json:"taskrouter_workspace_sid"`
URL string `json:"url"`
UiAttributes *interface{} `json:"ui_attributes,omitempty"`
UiDependencies *interface{} `json:"ui_dependencies,omitempty"`
UiLanguage *string `json:"ui_language,omitempty"`
UiVersion string `json:"ui_version"`
}
FetchConfigurationResponse defines the response fields for the retrieved configuration
type FetchConfigurationSkillResponse ¶ added in v0.6.0
type FetchConfigurationTaskQueueResponse ¶ added in v0.6.0
type FetchConfigurationWorkerChannelResponse ¶ added in v0.6.0
type UpdateConfigurationInput ¶
type UpdateConfigurationInput struct {
AccountSid string `validate:"required" json:"account_sid"`
Attributes *interface{} `json:"attributes,omitempty"`
CallRecordingEnabled *bool `json:"call_recording_enabled,omitempty"`
CallRecordingWebhookURL *string `json:"call_recording_webhook_url,omitempty"`
ChatServiceInstanceSid *string `json:"chat_service_instance_sid,omitempty"`
CrmAttributes *interface{} `json:"crm_attributes,omitempty"`
CrmCallbackURL *string `json:"crm_callback_url,omitempty"`
CrmEnabled *bool `json:"crm_enabled,omitempty"`
CrmFallbackURL *string `json:"crm_fallback_url,omitempty"`
CrmType *string `json:"crm_type,omitempty"`
Integrations *[]UpdateConfigurationIntegrationInput `json:"integrations,omitempty"`
MessagingServiceInstanceSid *string `json:"messaging_service_instance_sid,omitempty"`
OutboundCallFlows *interface{} `json:"outbound_call_flows,omitempty"`
PluginServiceAttributes *interface{} `json:"plugin_service_attributes,omitempty"`
PluginServiceEnabled *bool `json:"plugin_service_enabled,omitempty"`
PublicAttributes *interface{} `json:"public_attributes,omitempty"`
QueueStatsConfiguration *interface{} `json:"queue_stats_configuration,omitempty"`
ServerlessServiceSids *[]string `json:"serverless_service_sids,omitempty"`
TaskRouterSkills *[]UpdateConfigurationSkillInput `json:"taskrouter_skills,omitempty"`
TaskRouterTargetTaskQueueSid *string `json:"taskrouter_target_taskqueue_sid,omitempty"`
TaskRouterTargetWorkflowSid *string `json:"taskrouter_target_workflow_sid,omitempty"`
TaskRouterTaskQueues *[]UpdateConfigurationTaskQueueInput `json:"taskrouter_taskqueues,omitempty"`
TaskRouterWorkerAttributes *map[string]interface{} `json:"taskrouter_worker_attributes,omitempty"`
TaskRouterWorkerChannels *map[string][]UpdateConfigurationWorkerChannelInput `json:"taskrouter_worker_channels,omitempty"`
UiAttributes *interface{} `json:"ui_attributes,omitempty"`
UiDependencies *interface{} `json:"ui_dependencies,omitempty"`
UiLanguage *string `json:"ui_language,omitempty"`
UiVersion *string `json:"ui_version,omitempty"`
}
UpdateConfigurationInput defines input fields for updating a configuration resource
type UpdateConfigurationIntegrationInput ¶ added in v0.6.0
type UpdateConfigurationIntegrationResponse ¶ added in v0.6.0
type UpdateConfigurationResponse ¶
type UpdateConfigurationResponse struct {
AccountSid string `json:"account_sid"`
Attributes *interface{} `json:"attributes,omitempty"`
CallRecordingEnabled *bool `json:"call_recording_enabled,omitempty"`
CallRecordingWebhookURL *string `json:"call_recording_webhook_url,omitempty"`
ChatServiceInstanceSid *string `json:"chat_service_instance_sid,omitempty"`
CrmAttributes *interface{} `json:"crm_attributes,omitempty"`
CrmCallbackURL *string `json:"crm_callback_url,omitempty"`
CrmEnabled *bool `json:"crm_enabled,omitempty"`
CrmFallbackURL *string `json:"crm_fallback_url,omitempty"`
CrmType *string `json:"crm_type,omitempty"`
DateCreated time.Time `json:"date_created"`
DateUpdated *time.Time `json:"date_updated,omitempty"`
FlexServiceInstanceSid string `json:"flex_service_instance_sid"`
Integrations *[]UpdateConfigurationIntegrationResponse `json:"integrations,omitempty"`
MessagingServiceInstanceSid *string `json:"messaging_service_instance_sid,omitempty"`
OutboundCallFlows *interface{} `json:"outbound_call_flows,omitempty"`
PluginServiceAttributes *interface{} `json:"plugin_service_attributes,omitempty"`
PluginServiceEnabled *bool `json:"plugin_service_enabled,omitempty"`
PublicAttributes *interface{} `json:"public_attributes,omitempty"`
QueueStatsConfiguration *interface{} `json:"queue_stats_configuration,omitempty"`
RuntimeDomain string `json:"runtime_domain"`
ServerlessServiceSids *[]string `json:"serverless_service_sids,omitempty"`
ServiceVersion *string `json:"service_version,omitempty"`
Status string `json:"status"`
TaskRouterOfflineActivitySid string `json:"taskrouter_offline_activity_sid"`
TaskRouterSkills *[]UpdateConfigurationSkillResponse `json:"taskrouter_skills,omitempty"`
TaskRouterTargetTaskQueueSid string `json:"taskrouter_target_taskqueue_sid"`
TaskRouterTargetWorkflowSid string `json:"taskrouter_target_workflow_sid"`
TaskRouterTaskQueues *[]UpdateConfigurationTaskQueueResponse `json:"taskrouter_taskqueues,omitempty"`
TaskRouterWorkerAttributes *map[string]interface{} `json:"taskrouter_worker_attributes,omitempty"`
TaskRouterWorkerChannels *map[string][]UpdateConfigurationWorkerChannelResponse `json:"taskrouter_worker_channels,omitempty"`
TaskRouterWorkspaceSid string `json:"taskrouter_workspace_sid"`
URL string `json:"url"`
UiAttributes *interface{} `json:"ui_attributes,omitempty"`
UiDependencies *interface{} `json:"ui_dependencies,omitempty"`
UiLanguage *string `json:"ui_language,omitempty"`
UiVersion string `json:"ui_version"`
}
UpdateConfigurationResponse defines the response fields for the updated configuration