Documentation
¶
Overview ¶
Package flow contains auto-generated files. DO NOT MODIFY
Package flow contains auto-generated files. DO NOT MODIFY
Package flow contains auto-generated files. DO NOT MODIFY
Package flow contains auto-generated files. DO NOT MODIFY
Index ¶
- type Client
- func (c Client) Delete() error
- func (c Client) DeleteWithContext(context context.Context) error
- func (c Client) Fetch() (*FetchFlowResponse, error)
- func (c Client) FetchWithContext(context context.Context) (*FetchFlowResponse, error)
- func (c Client) Update(input *UpdateFlowInput) (*UpdateFlowResponse, error)
- func (c Client) UpdateWithContext(context context.Context, input *UpdateFlowInput) (*UpdateFlowResponse, error)
- type ClientProperties
- type FetchFlowResponse
- type UpdateFlowInput
- type UpdateFlowResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
Execution func(string) *execution.Client
Executions *executions.Client
Revision func(int) *revision.Client
Revisions *revisions.Client
TestUsers func() *test_users.Client
// contains filtered or unexported fields
}
Client for managing a specific flow resource See https://www.twilio.com/docs/studio/rest-api/v2/flow for more details
func New ¶
func New(client *client.Client, properties ClientProperties) *Client
New creates a new instance of the flow client
func (Client) Delete ¶
Delete removes a flow resource from the account See https://www.twilio.com/docs/studio/rest-api/v2/flow#delete-a-flow-resource for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) DeleteWithContext ¶
DeleteWithContext removes a flow resource from the account See https://www.twilio.com/docs/studio/rest-api/v2/flow#delete-a-flow-resource for more details
func (Client) Fetch ¶
func (c Client) Fetch() (*FetchFlowResponse, error)
Fetch retrieves a flow resource See https://www.twilio.com/docs/studio/rest-api/v2/flow#fetch-a-flow-resource for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) FetchWithContext ¶
func (c Client) FetchWithContext(context context.Context) (*FetchFlowResponse, error)
FetchWithContext retrieves a flow resource See https://www.twilio.com/docs/studio/rest-api/v2/flow#fetch-a-flow-resource for more details
func (Client) Update ¶
func (c Client) Update(input *UpdateFlowInput) (*UpdateFlowResponse, error)
Update modifies a flow resource See https://www.twilio.com/docs/studio/rest-api/v2/flow#update-a-flow-resource for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) UpdateWithContext ¶
func (c Client) UpdateWithContext(context context.Context, input *UpdateFlowInput) (*UpdateFlowResponse, error)
UpdateWithContext modifies a flow resource See https://www.twilio.com/docs/studio/rest-api/v2/flow#update-a-flow-resource for more details
type ClientProperties ¶
type ClientProperties struct {
Sid string
}
ClientProperties are the properties required to manage the flow resources
type FetchFlowResponse ¶
type FetchFlowResponse struct {
AccountSid string `json:"account_sid"`
CommitMessage *string `json:"commit_message,omitempty"`
DateCreated time.Time `json:"date_created"`
DateUpdated *time.Time `json:"date_updated,omitempty"`
Definition map[string]interface{} `json:"definition"`
Errors *[]interface{} `json:"errors,omitempty"`
FriendlyName string `json:"friendly_name"`
Revision int `json:"revision"`
Sid string `json:"sid"`
Status string `json:"status"`
URL string `json:"url"`
Valid bool `json:"valid"`
Warnings *[]interface{} `json:"warnings,omitempty"`
WebhookURL string `json:"webhook_url"`
}
FetchFlowResponse defines the response fields for the retrieved flow
type UpdateFlowInput ¶
type UpdateFlowInput struct {
CommitMessage *string `form:"CommitMessage,omitempty"`
Definition *string `form:"Definition,omitempty"`
FriendlyName *string `form:"FriendlyName,omitempty"`
Status string `validate:"required" form:"Status"`
}
UpdateFlowInput defines input fields for updating a flow resource
type UpdateFlowResponse ¶
type UpdateFlowResponse struct {
AccountSid string `json:"account_sid"`
CommitMessage *string `json:"commit_message,omitempty"`
DateCreated time.Time `json:"date_created"`
DateUpdated *time.Time `json:"date_updated,omitempty"`
Definition map[string]interface{} `json:"definition"`
Errors *[]interface{} `json:"errors,omitempty"`
FriendlyName string `json:"friendly_name"`
Revision int `json:"revision"`
Sid string `json:"sid"`
Status string `json:"status"`
URL string `json:"url"`
Valid bool `json:"valid"`
Warnings *[]interface{} `json:"warnings,omitempty"`
WebhookURL string `json:"webhook_url"`
}
UpdateFlowResponse defines the response fields for the updated flow
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package execution contains auto-generated files.
|
Package execution contains auto-generated files. |
|
context
Package context contains auto-generated files.
|
Package context contains auto-generated files. |
|
step
Package step contains auto-generated files.
|
Package step contains auto-generated files. |
|
step/context
Package context contains auto-generated files.
|
Package context contains auto-generated files. |
|
steps
Package steps contains auto-generated files.
|
Package steps contains auto-generated files. |
|
Package executions contains auto-generated files.
|
Package executions contains auto-generated files. |
|
Package revision contains auto-generated files.
|
Package revision contains auto-generated files. |
|
Package revisions contains auto-generated files.
|
Package revisions contains auto-generated files. |
|
Package test_users contains auto-generated files.
|
Package test_users contains auto-generated files. |