Documentation
¶
Overview ¶
Package execution contains auto-generated files. DO NOT MODIFY
Package execution contains auto-generated files. DO NOT MODIFY
Package execution contains auto-generated files. DO NOT MODIFY
Package execution contains auto-generated files. DO NOT MODIFY
Index ¶
- type Client
- func (c Client) Delete() error
- func (c Client) DeleteWithContext(context context.Context) error
- func (c Client) Fetch() (*FetchExecutionResponse, error)
- func (c Client) FetchWithContext(context context.Context) (*FetchExecutionResponse, error)
- func (c Client) Update(input *UpdateExecutionInput) (*UpdateExecutionResponse, error)
- func (c Client) UpdateWithContext(context context.Context, input *UpdateExecutionInput) (*UpdateExecutionResponse, error)
- type ClientProperties
- type FetchExecutionResponse
- type UpdateExecutionInput
- type UpdateExecutionResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
Context func() *context.Client
Step func(string) *step.Client
Steps *steps.Client
// contains filtered or unexported fields
}
Client for managing a specific execution resource See https://www.twilio.com/docs/studio/rest-api/v2/execution for more details
func New ¶
func New(client *client.Client, properties ClientProperties) *Client
New creates a new instance of the execution client
func (Client) Delete ¶
Delete removes a execution resource from the account See https://www.twilio.com/docs/studio/rest-api/v2/execution#delete-an-execution for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) DeleteWithContext ¶
DeleteWithContext removes a execution resource from the account See https://www.twilio.com/docs/studio/rest-api/v2/execution#delete-an-execution for more details
func (Client) Fetch ¶
func (c Client) Fetch() (*FetchExecutionResponse, error)
Fetch retrieves a execution resource See https://www.twilio.com/docs/studio/rest-api/v2/execution#fetch-a-single-execution for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) FetchWithContext ¶
func (c Client) FetchWithContext(context context.Context) (*FetchExecutionResponse, error)
FetchWithContext retrieves a execution resource See https://www.twilio.com/docs/studio/rest-api/v2/execution#fetch-a-single-execution for more details
func (Client) Update ¶
func (c Client) Update(input *UpdateExecutionInput) (*UpdateExecutionResponse, error)
Update modifies a execution resource See https://www.twilio.com/docs/studio/rest-api/v2/execution#update-an-execution for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) UpdateWithContext ¶
func (c Client) UpdateWithContext(context context.Context, input *UpdateExecutionInput) (*UpdateExecutionResponse, error)
UpdateWithContext modifies a execution resource See https://www.twilio.com/docs/studio/rest-api/v2/execution#update-an-execution for more details
type ClientProperties ¶
ClientProperties are the properties required to manage the execution resources
type FetchExecutionResponse ¶
type FetchExecutionResponse struct {
AccountSid string `json:"account_sid"`
ContactChannelAddress string `json:"contact_channel_address"`
Context interface{} `json:"context"`
DateCreated time.Time `json:"date_created"`
DateUpdated *time.Time `json:"date_updated,omitempty"`
FlowSid string `json:"flow_sid"`
Sid string `json:"sid"`
Status string `json:"status"`
URL string `json:"url"`
}
FetchExecutionResponse defines the response fields for the retrieved execution
type UpdateExecutionInput ¶
type UpdateExecutionInput struct {
Status string `validate:"required" form:"Status"`
}
UpdateExecutionInput defines input fields for updating a execution resource
type UpdateExecutionResponse ¶
type UpdateExecutionResponse struct {
AccountSid string `json:"account_sid"`
ContactChannelAddress string `json:"contact_channel_address"`
Context interface{} `json:"context"`
DateCreated time.Time `json:"date_created"`
DateUpdated *time.Time `json:"date_updated,omitempty"`
FlowSid string `json:"flow_sid"`
Sid string `json:"sid"`
Status string `json:"status"`
URL string `json:"url"`
}
UpdateExecutionResponse defines the response fields for the updated execution
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package context contains auto-generated files.
|
Package context contains auto-generated files. |
|
Package step contains auto-generated files.
|
Package step contains auto-generated files. |
|
context
Package context contains auto-generated files.
|
Package context contains auto-generated files. |
|
Package steps contains auto-generated files.
|
Package steps contains auto-generated files. |