Documentation
¶
Overview ¶
Package revision contains auto-generated files. DO NOT MODIFY
Package revision contains auto-generated files. DO NOT MODIFY
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client for managing a specific flow revision resource See https://www.twilio.com/docs/studio/rest-api/v2/flow-revision for more details
func New ¶
func New(client *client.Client, properties ClientProperties) *Client
New creates a new instance of the revision client
func (Client) Fetch ¶
func (c Client) Fetch() (*FetchRevisionResponse, error)
Fetch retrieves a flow revision resource See https://www.twilio.com/docs/studio/rest-api/v2/flow-revision#fetch-a-flowrevision-resource for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) FetchWithContext ¶
func (c Client) FetchWithContext(context context.Context) (*FetchRevisionResponse, error)
FetchWithContext retrieves a flow revision resource See https://www.twilio.com/docs/studio/rest-api/v2/flow-revision#fetch-a-flowrevision-resource for more details
type ClientProperties ¶
ClientProperties are the properties required to manage the revision resources
type FetchRevisionResponse ¶
type FetchRevisionResponse struct {
AccountSid string `json:"account_sid"`
CommitMessage *string `json:"commit_message,omitempty"`
DateCreated time.Time `json:"date_created"`
DateUpdated *time.Time `json:"date_updated,omitempty"`
Definition map[string]interface{} `json:"definition"`
Errors *[]interface{} `json:"errors,omitempty"`
FriendlyName string `json:"friendly_name"`
Revision int `json:"revision"`
Sid string `json:"sid"`
Status string `json:"status"`
URL string `json:"url"`
Valid bool `json:"valid"`
Warnings *[]interface{} `json:"warnings,omitempty"`
WebhookURL string `json:"webhook_url"`
}
FetchRevisionResponse defines the response fields for the retrieved flow revision