Documentation
¶
Overview ¶
Package task contains auto-generated files. DO NOT MODIFY
Package task contains auto-generated files. DO NOT MODIFY
Package task contains auto-generated files. DO NOT MODIFY
Package task contains auto-generated files. DO NOT MODIFY
Index ¶
- type Client
- func (c Client) Delete() error
- func (c Client) DeleteWithContext(context context.Context) error
- func (c Client) Fetch() (*FetchTaskResponse, error)
- func (c Client) FetchWithContext(context context.Context) (*FetchTaskResponse, error)
- func (c Client) Update(input *UpdateTaskInput) (*UpdateTaskResponse, error)
- func (c Client) UpdateWithContext(context context.Context, input *UpdateTaskInput) (*UpdateTaskResponse, error)
- type ClientProperties
- type FetchTaskResponse
- type UpdateTaskInput
- type UpdateTaskResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
Reservation func(string) *reservation.Client
Reservations *reservations.Client
// contains filtered or unexported fields
}
Client for managing a specific task resource See https://www.twilio.com/docs/taskrouter/api/task for more details
func New ¶
func New(client *client.Client, properties ClientProperties) *Client
New creates a new instance of the task client
func (Client) Delete ¶
Delete removes a task resource from the account See https://www.twilio.com/docs/taskrouter/api/task#delete-a-task-resource for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) DeleteWithContext ¶
DeleteWithContext removes a task resource from the account See https://www.twilio.com/docs/taskrouter/api/task#delete-a-task-resource for more details
func (Client) Fetch ¶
func (c Client) Fetch() (*FetchTaskResponse, error)
Fetch retrieves an task resource See https://www.twilio.com/docs/taskrouter/api/task#fetch-a-task-resource for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) FetchWithContext ¶
func (c Client) FetchWithContext(context context.Context) (*FetchTaskResponse, error)
FetchWithContext retrieves an task resource See https://www.twilio.com/docs/taskrouter/api/task#fetch-a-task-resource for more details
func (Client) Update ¶
func (c Client) Update(input *UpdateTaskInput) (*UpdateTaskResponse, error)
Update modifies a task resource See https://www.twilio.com/docs/taskrouter/api/task#update-a-task-resource for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) UpdateWithContext ¶
func (c Client) UpdateWithContext(context context.Context, input *UpdateTaskInput) (*UpdateTaskResponse, error)
UpdateWithContext modifies a task resource See https://www.twilio.com/docs/taskrouter/api/task#update-a-task-resource for more details
type ClientProperties ¶
ClientProperties are the properties required to manage the task resources
type FetchTaskResponse ¶
type FetchTaskResponse struct {
AccountSid string `json:"account_sid"`
Age int `json:"age"`
AssignmentStatus string `json:"assignment_status"`
Attributes interface{} `json:"attributes"`
DateCreated time.Time `json:"date_created"`
DateUpdated *time.Time `json:"date_updated,omitempty"`
Priority *int `json:"priority,omitempty"`
Reason *string `json:"reason,omitempty"`
Sid string `json:"sid"`
TaskChannelSid *string `json:"task_channel_sid,omitempty"`
TaskChannelUniqueName *string `json:"task_channel_unique_name,omitempty"`
TaskQueueEnteredDate *time.Time `json:"task_queue_entered_date,omitempty"`
TaskQueueFriendlyName *string `json:"task_queue_friendly_name,omitempty"`
TaskQueueSid *string `json:"task_queue_sid,omitempty"`
Timeout int `json:"timeout"`
URL string `json:"url"`
WorkflowFriendlyName *string `json:"workflow_friendly_name,omitempty"`
WorkflowSid *string `json:"workflow_sid,omitempty"`
WorkspaceSid string `json:"workspace_sid"`
}
FetchTaskResponse defines the response fields for the retrieved task
type UpdateTaskInput ¶
type UpdateTaskInput struct {
AssignmentStatus *string `form:"AssignmentStatus,omitempty"`
Attributes *string `form:"Attributes,omitempty"`
Priority *int `form:"Priority,omitempty"`
Reason *string `form:"Reason,omitempty"`
TaskChannel *string `form:"TaskChannel,omitempty"`
}
UpdateTaskInput defines input fields for updating a task resource
type UpdateTaskResponse ¶
type UpdateTaskResponse struct {
AccountSid string `json:"account_sid"`
Age int `json:"age"`
AssignmentStatus string `json:"assignment_status"`
Attributes interface{} `json:"attributes"`
DateCreated time.Time `json:"date_created"`
DateUpdated *time.Time `json:"date_updated,omitempty"`
Priority *int `json:"priority,omitempty"`
Reason *string `json:"reason,omitempty"`
Sid string `json:"sid"`
TaskChannelSid *string `json:"task_channel_sid,omitempty"`
TaskChannelUniqueName *string `json:"task_channel_unique_name,omitempty"`
TaskQueueEnteredDate *time.Time `json:"task_queue_entered_date,omitempty"`
TaskQueueFriendlyName *string `json:"task_queue_friendly_name,omitempty"`
TaskQueueSid *string `json:"task_queue_sid,omitempty"`
Timeout int `json:"timeout"`
URL string `json:"url"`
WorkflowFriendlyName *string `json:"workflow_friendly_name,omitempty"`
WorkflowSid *string `json:"workflow_sid,omitempty"`
WorkspaceSid string `json:"workspace_sid"`
}
UpdateTaskResponse defines the response fields for the updated task
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package reservation contains auto-generated files.
|
Package reservation contains auto-generated files. |
|
Package reservations contains auto-generated files.
|
Package reservations contains auto-generated files. |