Documentation
¶
Overview ¶
Package rate_limit contains auto-generated files. DO NOT MODIFY
Package rate_limit contains auto-generated files. DO NOT MODIFY
Package rate_limit contains auto-generated files. DO NOT MODIFY
Package rate_limit contains auto-generated files. DO NOT MODIFY
Index ¶
- type Client
- func (c Client) Delete() error
- func (c Client) DeleteWithContext(context context.Context) error
- func (c Client) Fetch() (*FetchRateLimitResponse, error)
- func (c Client) FetchWithContext(context context.Context) (*FetchRateLimitResponse, error)
- func (c Client) Update(input *UpdateRateLimitInput) (*UpdateRateLimitResponse, error)
- func (c Client) UpdateWithContext(context context.Context, input *UpdateRateLimitInput) (*UpdateRateLimitResponse, error)
- type ClientProperties
- type FetchRateLimitResponse
- type UpdateRateLimitInput
- type UpdateRateLimitResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
Bucket func(string) *bucket.Client
Buckets *buckets.Client
// contains filtered or unexported fields
}
Client for managing a specific rate limit resource See https://www.twilio.com/docs/verify/api/service-rate-limits for more details
func New ¶
func New(client *client.Client, properties ClientProperties) *Client
New creates a new instance of the rate limit client
func (Client) Delete ¶
Delete removes a rate limit resource from the account See https://www.twilio.com/docs/verify/api/service-rate-limits#delete-a-rate-limit for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) DeleteWithContext ¶
DeleteWithContext removes a rate limit resource from the account See https://www.twilio.com/docs/verify/api/service-rate-limits#delete-a-rate-limit for more details
func (Client) Fetch ¶
func (c Client) Fetch() (*FetchRateLimitResponse, error)
Fetch retrieves a rate limit resource See https://www.twilio.com/docs/verify/api/service-rate-limits#fetch-a-rate-limit for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) FetchWithContext ¶
func (c Client) FetchWithContext(context context.Context) (*FetchRateLimitResponse, error)
FetchWithContext retrieves a rate limit resource See https://www.twilio.com/docs/verify/api/service-rate-limits#fetch-a-rate-limit for more details
func (Client) Update ¶
func (c Client) Update(input *UpdateRateLimitInput) (*UpdateRateLimitResponse, error)
Update modifies a rate limit resource See https://www.twilio.com/docs/verify/api/service-rate-limits#update-a-rate-limit for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information
func (Client) UpdateWithContext ¶
func (c Client) UpdateWithContext(context context.Context, input *UpdateRateLimitInput) (*UpdateRateLimitResponse, error)
UpdateWithContext modifies a rate limit resource See https://www.twilio.com/docs/verify/api/service-rate-limits#update-a-rate-limit for more details
type ClientProperties ¶
ClientProperties are the properties required to manage the rate limit resources
type FetchRateLimitResponse ¶
type FetchRateLimitResponse struct {
AccountSid string `json:"account_sid"`
DateCreated time.Time `json:"date_created"`
DateUpdated *time.Time `json:"date_updated,omitempty"`
Description *string `json:"description,omitempty"`
ServiceSid string `json:"service_sid"`
Sid string `json:"sid"`
URL string `json:"url"`
UniqueName string `json:"unique_name"`
}
FetchRateLimitResponse defines the response fields for the retrieved rate limit
type UpdateRateLimitInput ¶
type UpdateRateLimitInput struct {
Description *string `form:"Description,omitempty"`
}
UpdateRateLimitInput defines input fields for updating a rate limit resource
type UpdateRateLimitResponse ¶
type UpdateRateLimitResponse struct {
AccountSid string `json:"account_sid"`
DateCreated time.Time `json:"date_created"`
DateUpdated *time.Time `json:"date_updated,omitempty"`
Description *string `json:"description,omitempty"`
ServiceSid string `json:"service_sid"`
Sid string `json:"sid"`
URL string `json:"url"`
UniqueName string `json:"unique_name"`
}
UpdateRateLimitResponse defines the response fields for the updated rate limit