Documentation
¶
Overview ¶
Package webhook contains auto-generated files. DO NOT MODIFY
Package webhook contains auto-generated files. DO NOT MODIFY
Package webhook contains auto-generated files. DO NOT MODIFY
Package webhook contains auto-generated files. DO NOT MODIFY
Index ¶
- type Client
- func (c Client) Delete() error
- func (c Client) DeleteWithContext(context context.Context) error
- func (c Client) Fetch() (*FetchWebhookResponse, error)
- func (c Client) FetchWithContext(context context.Context) (*FetchWebhookResponse, error)
- func (c Client) Update(input *UpdateWebhookInput) (*UpdateWebhookResponse, error)
- func (c Client) UpdateWithContext(context context.Context, input *UpdateWebhookInput) (*UpdateWebhookResponse, error)
- type ClientProperties
- type FetchWebhookResponse
- type UpdateWebhookInput
- type UpdateWebhookResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client for managing a specific webhook resource See https://www.twilio.com/docs/verify/api/webhooks for more details This client is currently in beta and subject to change. Please use with caution
func New ¶
func New(client *client.Client, properties ClientProperties) *Client
New creates a new instance of the webhook client
func (Client) Delete ¶
Delete removes a webhook resource from the account See https://www.twilio.com/docs/verify/api/webhooks#delete-a-webhook-resource for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information This resource is currently in beta and subject to change. Please use with caution
func (Client) DeleteWithContext ¶
DeleteWithContext removes a webhook resource from the account See https://www.twilio.com/docs/verify/api/webhooks#delete-a-webhook-resource for more details This resource is currently in beta and subject to change. Please use with caution
func (Client) Fetch ¶
func (c Client) Fetch() (*FetchWebhookResponse, error)
Fetch retrieves a webhook resource See https://www.twilio.com/docs/verify/api/webhooks#fetch-a-webhook-resource for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information This resource is currently in beta and subject to change. Please use with caution
func (Client) FetchWithContext ¶
func (c Client) FetchWithContext(context context.Context) (*FetchWebhookResponse, error)
FetchWithContext retrieves a webhook resource See https://www.twilio.com/docs/verify/api/webhooks#fetch-a-webhook-resource for more details This resource is currently in beta and subject to change. Please use with caution
func (Client) Update ¶
func (c Client) Update(input *UpdateWebhookInput) (*UpdateWebhookResponse, error)
Update modifies a webhook resource See https://www.twilio.com/docs/verify/api/webhooks#update-a-webhook-resource for more details Context is defaulted to Background. See https://golang.org/pkg/context/#Background for more information This resource is currently in beta and subject to change. Please use with caution
func (Client) UpdateWithContext ¶
func (c Client) UpdateWithContext(context context.Context, input *UpdateWebhookInput) (*UpdateWebhookResponse, error)
UpdateWithContext modifies a webhook resource See https://www.twilio.com/docs/verify/api/webhooks#update-a-webhook-resource for more details This resource is currently in beta and subject to change. Please use with caution
type ClientProperties ¶
ClientProperties are the properties required to manage the webhook resources
type FetchWebhookResponse ¶
type FetchWebhookResponse struct {
AccountSid string `json:"account_sid"`
DateCreated time.Time `json:"date_created"`
DateUpdated *time.Time `json:"date_updated,omitempty"`
EventTypes []string `json:"event_types"`
FriendlyName string `json:"friendly_name"`
ServiceSid string `json:"service_sid"`
Sid string `json:"sid"`
Status string `json:"status"`
URL string `json:"url"`
Version string `json:"version"`
WebhookMethod string `json:"webhook_method"`
WebhookURL string `json:"webhook_url"`
}
FetchWebhookResponse defines the response fields for the retrieved webhook
type UpdateWebhookInput ¶
type UpdateWebhookInput struct {
EventTypes *[]string `form:"EventTypes,omitempty"`
FriendlyName *string `form:"FriendlyName,omitempty"`
Status *string `form:"Status,omitempty"`
Version *string `form:"Version,omitempty"`
WebhookURL *string `form:"WebhookUrl,omitempty"`
}
UpdateWebhookInput defines input fields for updating a webhook resource
type UpdateWebhookResponse ¶
type UpdateWebhookResponse struct {
AccountSid string `json:"account_sid"`
DateCreated time.Time `json:"date_created"`
DateUpdated *time.Time `json:"date_updated,omitempty"`
EventTypes []string `json:"event_types"`
FriendlyName string `json:"friendly_name"`
ServiceSid string `json:"service_sid"`
Sid string `json:"sid"`
Status string `json:"status"`
URL string `json:"url"`
Version string `json:"version"`
WebhookMethod string `json:"webhook_method"`
WebhookURL string `json:"webhook_url"`
}
UpdateWebhookResponse defines the response fields for the updated webhook